<?php
/**
 *  plugins/qmailadmin_login/setup.php -- Displays the main frameset
 *
 * Copyright (c) 1999-2004 The SquirrelMail Project Team
 * Copyright (c) 2004-2005 Tomas Kuliavas <tokul@users.sourceforge.net>
 * This file is part of SquirrelMail QmailAdmin Login plugin. Original script
 * version was provided by SquirrelMail webmail package and licensed under GPL.
 *
 * QmailAdmin Login plugin is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * QmailAdmin Login plugin is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with QmailAdmin Login plugin; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Redirects to the login page.
 *
 * @version $Id: index.php,v 1.3 2005/06/26 07:10:35 tokul Exp $
 * @package sm-plugins
 * @subpackage qmailadmin_login
 */
header("Location: ../../src/index.php\n\n");
?>
