<?php
/**
 * Default configuration file.
 *
 * Copyright (c) 2004-2005 Tomas Kuliavas <tokul@users.sourceforge.net>
 * This file is part of SquirrelMail QmailAdmin Login plugin.
 *
 * QmailAdmin Login plugin is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * QmailAdmin Login plugin is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with QmailAdmin Login plugin; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * @version $Id: config_default.php,v 1.5 2005/07/27 16:08:20 tokul Exp $
 * @package sm-plugins
 * @subpackage qmailadmin_login
 */

/**
 * qmailadmin cgi URL
 *
 * WARNING: default configuration is as secure as your webmail install.
 * If webmail installation is running on standard http service, web traffic
 * and connection to administration script are not secured. Setup webmail on
 * SSL/TLS site, if you want to protect transfered information. Use of https:
 * URL in this option is not recommened, if webmail remains in http:. Mixed http: 
 * and https: content can cause warnings in browsers.
 * @global string $qmlogin_cgi_url
 */
$qmlogin_cgi_url='/cgi-bin/qmailadmin';

/**
 * display of iframe border control
 * @global bool $qmlogin_frameborder
 */
$qmlogin_frameborder=true;

/**
 * Controls automatic login into qmailadmin
 *
 * WARNING: current implementation is not secure. Password information is 
 * visible in proxy and webserver logs. Don't enable it, unless you really want
 * it.
 * @global bool $qmlogin_autologin
 * @since 1.1
 */
$qmlogin_autologin=false;
?>